<?php

/**
 * @file
 * Contains \Drupal\tcmb\Plugin\Block\TcmbCurrencyBlock
 */

namespace Drupal\tcmb\Plugin\Block;

use Drupal\block\BlockBase;
use Drupal\block\Annotation\block;
use Drupal\Core\Annotation\Translation;

/**
 * Provides a 'Tcmb Currency' block.
 *
 * @Block (
 *  id = "tcmb_currency_block",
 *  admin_label = @Translation("Tcmb: currency"),
 *  module = "tcmb"
 *  )
 */
class TcmbCurrencyBlock extends BlockBase {
  public function build() {
    $tcmb_currency_codes = config('tcmb.settings')->get('tcmb_currency_codes', array());
    $tcmb_currency_xml = new \Domdocument;
    $tcmb_currency_xml->load('http://www.tcmb.gov.tr/kurlar/today.xml');
    $created = $tcmb_currency_xml->getElementsByTagName('Tarih_Date')->item(0)->getAttribute('Tarih');
    $datetime = \DateTime::createFromFormat('d.m.Y', $created);
    $updated = $datetime->format('Y-m-d');
    if (config('tcmb.settings')->get('tcmb_show_currency_block_title')) {
      $this->configuration['label'] = t('TCMB rates for @updated', array('@updated' => date('d-m-Y', strtotime($updated))));
    }
    else {
      $this->configuration['label'] = '';
    }
    $records = db_select('tcmb', 't')
      ->fields('t', array(
        'currency_name',
        'currency_code',
        'updated',
        'buying',
        'selling',
      ))
      ->condition('currency_code', $tcmb_currency_codes, 'IN')
      ->orderBy('updated', 'DESC')
      ->orderBy('currency_code')
      ->groupBy('currency_code');
    $results = $records->execute()->fetchAll(\PDO::FETCH_ASSOC);
    $header = array(t('Currency'), t('Buying'), t('Selling'));
    $rows = array();
    foreach ($results as $result) {
      $title = $result['currency_name'];
      $image = drupal_get_path('module', 'tcmb') . '/png/' . strtolower($result['currency_code']) . '.png';
      $rows[] = array('data' => array(theme('image', array('uri' => $image, 'alt' => $title, 'title' => $title)) . " " . $result['currency_code'], $result['buying'], $result['selling']));
    }
    if (isset($rows)) { 
      return array(
        '#theme' => 'table',
        '#header' => $header,
        '#rows' => $rows,
        '#suffix' => config('tcmb.settings')->get('tcmb_show_currency_block_footer') ? t('Exchange rates are updated once a day on 15:30 on weekdays.') : '',
      );
    }
  }
}
