<?php

/**
 * @file
 * Contains \Drupal\tcmb\Plugin\Block\TcmbCurrencyBlock
 */

namespace Drupal\tcmb\Plugin\Block;

use Drupal\block\BlockBase;
use Drupal\block\Annotation\block;
use Drupal\Core\Annotation\Translation;

/**
 * Provides a 'Tcmb Currency' block.
 *
 * @Block (
 *  id = "tcmb_gold_block",
 *  admin_label = @Translation("Tcmb: gold"),
 *  module = "tcmb"
 *  )
 */
class TcmbGoldBlock extends BlockBase {
  public function build() {
    $tcmb_gold_xml = new \DomDocument();
    $tcmb_gold_xml->load('http://xml.altinkaynak.com.tr/altin.xml');
    $tcmb_gold_xpath = new \DOMXPath($tcmb_gold_xml);
    $query = "//DOVIZ[ADI='Tarih']";
    $results = $tcmb_gold_xpath->query($query);
    $tcmb_gold_date = $results->item(0)->getElementsByTagName('ALIS')->item(0)->nodeValue;
    if (config('tcmb.settings')->get('tcmb_show_gold_block_title')) {
      $this->configuration['label'] = t('TCMB rates for !tcmb_gold_date', array('!tcmb_gold_date' => $tcmb_gold_date));
    }
    else {
      $this->configuration['label'] = '';
    }
    $header = array(t('Gold code'), t('Buying'), t('Selling'));
    $gold = array();
    $golden = tcmb_gold_codes();
    $tcmb_gold_codes = config('tcmb.settings')->get('tcmb_gold_codes');
    if (!$tcmb_gold_codes) {
      return;
    }
    foreach ($tcmb_gold_codes as $tcmb_gold_code) {
      if (!$tcmb_gold_code) {
        continue;
      }
      $query = "//DOVIZ[ADI='$tcmb_gold_code']";
      $title = $golden[$tcmb_gold_code];
      $image = drupal_get_path('module', 'tcmb') . '/png/gold.png';
      $results = $tcmb_gold_xpath->query($query);
      if ($results->length < 1) {
        drupal_set_message(t('A problem occurred. Please try again later.'));
      }
      else {
        $buy = $results->item(0)->getElementsByTagName('ALIS')->item(0)->nodeValue;
        $sell = $results->item(0)->getElementsByTagName('SATIS')->item(0)->nodeValue;
        $rows[] = array(array('data' => theme('image', array('uri' => $image, 'alt' => $title, 'title' => $title)) . " " . check_plain($title)), check_plain($buy), check_plain($sell));
      }
    }
    if (isset($rows)) {
      return array(
        '#theme' => 'table',
        '#header' => $header,
        '#rows' => $rows,
        '#suffix' => config('tcmb.settings')->get('tcmb_show_gold_block_footer') ? t('Gold rates are updated every 5 minutes.') : '',
      );
    }
  }
}
